@@ -15,7 +15,7 @@ package API::GitForge::Role::GitForge;
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-$API::GitForge::Role::GitForge::VERSION = '0.004';
+$API::GitForge::Role::GitForge::VERSION = '0.005';
 
 use 5.028;
 use strict;
@@ -80,7 +80,8 @@ sub clean_fork {
     # but that hangs indefinitely when pushing to (at least) Debian's
     # GitLab instance.  So just bypass Git::Wrapper and do the push
     # ourselves for now
-    system qw(git -C), $git->dir, "push", $fork_uri, "master:gitforge";
+    system qw(git -C), $git->dir, "push", $fork_uri, "master:gitforge"
+      or croak "failed to push the gitforge branch to $fork_uri";
 
     $self->_clean_config_fork($_[0]);
 
@@ -122,7 +123,7 @@ API::GitForge::Role::GitForge - role implementing generic git forge operations
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
